EXPORTS
	??1CCntTest@@EAE@XZ @ 1 NONAME ; private: virtual __thiscall CCntTest::~CCntTest(void)
	??1CVCardTestStore@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CVCardTestStore::~CVCardTestStore(void)
	?AddContactL@@YAJPAVCContactDatabase@@VTUid@@1ABVTDesC16@@@Z @ 3 NONAME ; long __cdecl AddContactL(class CContactDatabase *,class TUid,class TUid,class TDesC16 const &)
	?AddFieldL@@YAXPAVCContactItem@@IVTUid@@1@Z @ 4 NONAME ; void __cdecl AddFieldL(class CContactItem *,unsigned int,class TUid,class TUid)
	?AddFieldL@@YAXPAVCContactItemFieldSet@@IVTUid@@1@Z @ 5 NONAME ; void __cdecl AddFieldL(class CContactItemFieldSet *,unsigned int,class TUid,class TUid)
	?AdjustContactAccessCountL@CCntTest@@QAEXJH@Z @ 6 NONAME ; public: void __thiscall CCntTest::AdjustContactAccessCountL(long,int)
	?CheckContactDoesNotExist@CCntTest@@QAEXJ@Z @ 7 NONAME ; public: void __thiscall CCntTest::CheckContactDoesNotExist(long)
	?CheckDeletedContact@CCntTest@@QAEXJ@Z @ 8 NONAME ; public: void __thiscall CCntTest::CheckDeletedContact(long)
	?CleanUpResetAndDestroy@@YAXPAX@Z @ 9 NONAME ; void __cdecl CleanUpResetAndDestroy(void *)
	?CloseDatabase@CCntTest@@QAEXXZ @ 10 NONAME ; public: void __thiscall CCntTest::CloseDatabase(void)
	?CompareFields@CCntTest@@QAEHAAVCContactItemField@@0@Z @ 11 NONAME ; public: int __thiscall CCntTest::CompareFields(class CContactItemField &,class CContactItemField &)
	?CompareItemField@@YAHABVCContactItemField@@0H@Z @ 12 NONAME ; int __cdecl CompareItemField(class CContactItemField const &,class CContactItemField const &,int)
	?CompareItemFields@@YAHPAVCContactItem@@0HH@Z @ 13 NONAME ; int __cdecl CompareItemFields(class CContactItem *,class CContactItem *,int,int)
	?ConstructL@CCntTest@@QAEXAAVRTest@@ABVTDesC16@@@Z @ 14 NONAME ; void CCntTest::ConstructL(class RTest &, class TDesC16 const &)
	?ConstructL@CVCardTestStore@@AAEXW4TVCardStoreType@@PAVRFs@@H@Z @ 15 NONAME ; private: void __thiscall CVCardTestStore::ConstructL(enum TVCardStoreType,class RFs *,int)
	?ContactUidLC@CCntTest@@QAEPAVHBufC16@@J_J@Z @ 16 NONAME ; public: class HBufC16 * __thiscall CCntTest::ContactUidLC(long,long long)
	?CreateDatabaseL@CCntTest@@QAEPAVCContactDatabase@@XZ @ 17 NONAME ; public: class CContactDatabase * __thiscall CCntTest::CreateDatabaseL(void)
	?DeleteAllTemplateFieldsL@CCntTest@@QAEXXZ @ 18 NONAME ; public: void __thiscall CCntTest::DeleteAllTemplateFieldsL(void)
	?DeleteContact@CCntTest@@QAEXJ@Z @ 19 NONAME ; public: void __thiscall CCntTest::DeleteContact(long)
	?DeleteDatabaseL@CCntTest@@QAEXXZ @ 20 NONAME ; public: void __thiscall CCntTest::DeleteDatabaseL(void)
	?EndTestLib@CCntTest@@QAEXH@Z @ 21 NONAME ; public: void __thiscall CCntTest::EndTestLib(int)
	?ExportContactLC@CCntTest@@QAEPAVCVCardTestStore@@JIW4TVCardStoreType@@H@Z @ 22 NONAME ; public: class CVCardTestStore * __thiscall CCntTest::ExportContactLC(long,unsigned int,enum TVCardStoreType,int)
	?ExportContactsL@@YAPAVCVCardTestStore@@PAVCContactDatabase@@PBVCContactIdArray@@IW4TVCardStoreType@@PAVRFs@@H@Z @ 23 NONAME ; class CVCardTestStore * __cdecl ExportContactsL(class CContactDatabase *,class CContactIdArray const *,unsigned int,enum TVCardStoreType,class RFs *,int)
	?ExportContactsLC@CCntTest@@QAEPAVCVCardTestStore@@PBVCContactIdArray@@IW4TVCardStoreType@@H@Z @ 24 NONAME ; public: class CVCardTestStore * __thiscall CCntTest::ExportContactsLC(class CContactIdArray const *,unsigned int,enum TVCardStoreType,int)
	?FieldText@@YA?AVTPtrC16@@AAVCContactItem@@VTUid@@@Z @ 25 NONAME ; class TPtrC16  __cdecl FieldText(class CContactItem &,class TUid)
	?ImportContacts1by1L@CCntTest@@QAEXPAVCVCardTestStore@@I@Z @ 26 NONAME ; public: void __thiscall CCntTest::ImportContacts1by1L(class CVCardTestStore *,unsigned int)
	?ImportContactsL@@YAPAV?$CArrayPtr@VCContactItem@@@@PAVCContactDatabase@@PAVCVCardTestStore@@I@Z @ 27 NONAME ; class CArrayPtr<class CContactItem> * __cdecl ImportContactsL(class CContactDatabase *,class CVCardTestStore *,unsigned int)
	?ImportContactsL@CCntTest@@QAEPAV?$CArrayPtr@VCContactItem@@@@PAVCVCardTestStore@@I@Z @ 28 NONAME ; public: class CArrayPtr<class CContactItem> * __thiscall CCntTest::ImportContactsL(class CVCardTestStore *,unsigned int)
	?ImportContactsLC@CCntTest@@QAEPAV?$CArrayPtr@VCContactItem@@@@PAVCVCardTestStore@@I@Z @ 29 NONAME ; public: class CArrayPtr<class CContactItem> * __thiscall CCntTest::ImportContactsLC(class CVCardTestStore *,unsigned int)
	?InsertFieldL@@YAXAAVCContactItem@@HIVTUid@@1@Z @ 30 NONAME ; void __cdecl InsertFieldL(class CContactItem &,int,unsigned int,class TUid,class TUid)
	?InsertFieldL@@YAXAAVCContactItem@@HIVTUid@@1ABVTDesC16@@@Z @ 31 NONAME ; void __cdecl InsertFieldL(class CContactItem &,int,unsigned int,class TUid,class TUid,class TDesC16 const &)
	?LockServerProcessCount@CCntTest@@QBEHHHH@Z @ 32 NONAME ; public: int __thiscall CCntTest::LockServerProcessCount(int,int,int)const 
	?LockServerSessionExists@CCntTest@@QBEHH@Z @ 33 NONAME ; public: int __thiscall CCntTest::LockServerSessionExists(int)const 
	?NewL@CVCardTestStore@@SAPAV1@W4TVCardStoreType@@PAVRFs@@H@Z @ 34 NONAME ; public: static class CVCardTestStore * __cdecl CVCardTestStore::NewL(enum TVCardStoreType,class RFs *,int)
	?NewLC@CVCardTestStore@@SAPAV1@W4TVCardStoreType@@PAVRFs@@H@Z @ 35 NONAME ; public: static class CVCardTestStore * __cdecl CVCardTestStore::NewLC(enum TVCardStoreType,class RFs *,int)
	?OpenDatabaseL@CCntTest@@QAEPAVCContactDatabase@@XZ @ 36 NONAME ; public: class CContactDatabase * __thiscall CCntTest::OpenDatabaseL(void)
	?PrintfNewline@CCntTest@@QBEXXZ @ 37 NONAME ; public: void __thiscall CCntTest::PrintfNewline(void)const 
	?SelectDriveL@CCntTest@@QAEXXZ @ 38 NONAME ; public: void __thiscall CCntTest::SelectDriveL(void)
	?SetNameL@@YAXAAVCContactItem@@VTUid@@1ABVTDesC16@@H@Z @ 39 NONAME ; void __cdecl SetNameL(class CContactItem &,class TUid,class TUid,class TDesC16 const &,int)
	?SetUserFlags@@YAXAAVCContactItemFieldSet@@I@Z @ 40 NONAME ; void __cdecl SetUserFlags(class CContactItemFieldSet &,unsigned int)
	?SetUserFlags@@YAXAAVCContactItemFieldSet@@IH@Z @ 41 NONAME ; void __cdecl SetUserFlags(class CContactItemFieldSet &,unsigned int,int)
	?SetUserFlags@@YAXPAVCContactItem@@I@Z @ 42 NONAME ; void __cdecl SetUserFlags(class CContactItem *,unsigned int)
	?SetUserFlags@@YAXPAVCContactItem@@IH@Z @ 43 NONAME ; void __cdecl SetUserFlags(class CContactItem *,unsigned int,int)
	?Store@CVCardTestStore@@QBEPAVCStreamStore@@XZ @ 44 NONAME ; public: class CStreamStore * __thiscall CVCardTestStore::Store(void)const 
	?TestAccessCount@CCntTest@@QAEXJH@Z @ 45 NONAME ; public: void __thiscall CCntTest::TestAccessCount(long,int)
	?TestField@CCntTest@@QAEXAAVCContactItemField@@IVTUid@@1@Z @ 46 NONAME ; public: void __thiscall CCntTest::TestField(class CContactItemField &,unsigned int,class TUid,class TUid)
	?TestLockServerExists@CCntTest@@QBEXXZ @ 47 NONAME ; public: void __thiscall CCntTest::TestLockServerExists(void)const 
	?TestNoLockServer@CCntTest@@QBEXXZ @ 48 NONAME ; public: void __thiscall CCntTest::TestNoLockServer(void)const 
	?TestGroupStateL@@YAHPAVCContactDatabase@@HH@Z @ 49 NONAME ; int __cdecl TestGroupStateL(class CContactDatabase *,int,int)
	?ProfileEnd@CCntTest@@SAHH@Z @ 50 NONAME ; int CCntTest::ProfileEnd(int)
	?ProfileReset@CCntTest@@SAHHH@Z @ 51 NONAME ; int CCntTest::ProfileReset(int, int)
	?ProfileResult@CCntTest@@SAHPAVTCntProfile@@HH@Z @ 52 NONAME ; int CCntTest::ProfileResult(class TCntProfile *, int, int)
	?ProfileStart@CCntTest@@SAHH@Z @ 53 NONAME ; int CCntTest::ProfileStart(int)
	?TestLockServerCloses@CCntTest@@QBEXXZ @ 54 NONAME ; void CCntTest::TestLockServerCloses(void) const
	?GetFullDbName@@YAPAVHBufC16@@ABVTDesC16@@@Z @ 55 NONAME ; class HBufC16 * GetFullDbName(class TDesC16 const &)
	??0TCntPerfTimer@@QAE@XZ @ 56 NONAME ; TCntPerfTimer::TCntPerfTimer(void)
	?ResetTimer@TCntPerfTimer@@QAEXXZ @ 57 NONAME ; void TCntPerfTimer::ResetTimer(void)
	?Result@TCntPerfTimer@@QAEIXZ @ 58 NONAME ; unsigned int TCntPerfTimer::Result(void)
	?StartTimer@TCntPerfTimer@@QAEXXZ @ 59 NONAME ; void TCntPerfTimer::StartTimer(void)
	?StopTimer@TCntPerfTimer@@QAEXXZ @ 60 NONAME ; void TCntPerfTimer::StopTimer(void)
	?DbShouldBeInDamagedState@@YAHPAVCContactDatabase@@@Z @ 61 NONAME ; int DbShouldBeInDamagedState(class CContactDatabase *)
	?ReadContactFromDamagedDbLC@@YAPAVCContactItem@@PAVCContactDatabase@@J@Z @ 62 NONAME ; class CContactItem * ReadContactFromDamagedDbLC(class CContactDatabase *, long)

